OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Tallennetaan...",
    "Download this revision" : "Lataa tämä versio",
    "Restore this revision" : "Palauta tähän versioon",
    "Latest revision" : "Viimeisin versio",
    "More versions..." : "Lisää versioita...",
    "Just now" : "Juuri nyt",
    "Failed to revert the document to older version" : "Asiakirjan palauttaminen aikaisempaan versioon epäonnistui",
    "Save" : "Tallenna",
    "Loading documents..." : "Ladataan asiakirjoja...",
    "Edit" : "Muokkaa",
    "New Document" : "Uusi asiakirja",
    "New Spreadsheet" : "Uusi taulukko",
    "New Presentation" : "Uusi esitys",
    "Could not create file" : "Tiedoston luominen epäonnistui",
    "New Document.odt" : "Uusi asiakirja.odt",
    "New Spreadsheet.ods" : "Uusi taulukko.ods",
    "New Presentation.odp" : "Uusi esitys.odp",
    "New Document.docx" : "Uusi asiakirja.docx",
    "New Spreadsheet.xlsx" : "Uusi taulukko.xlsx",
    "New Presentation.pptx" : "Uusi esitys.pptx",
    "Can't create document" : "Asiakirjan luominen epäonnistui",
    "Saved" : "Tallennettu",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Tallennettu virheen kanssa: Collabora Onlinen tulee käyttää palvelimen kanssa samaa protokollaa.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Collabora Online -palvelin",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL-osoite (ja portti) Collabora Online -palvelimelle, joka tarjoaa mukkaustoiminnot WOPI-asiakkaana.",
    "Apply" : "Toteuta",
    "Use OOXML by default for new files" : "Käytä OOXML:ää oletuksena uusille tiedostoille",
    "Wrong password. Please retry." : "Väärä salasana. Yritä uudelleen.",
    "Password" : "Salasana",
    "OK" : "OK",
    "Guest %s" : "Vieras %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Linkki on vanhentunut tai se ei ole ollutkaan toimiva. Ota yhteyttä henkilöön, jolta sait linkin saadaksesi lisätietoja."
},
"nplurals=2; plural=(n != 1);");
